@@ -23,7 +23,7 @@ import xapian
 
 import softwarecenter.paths
 
-from gi.repository import GObject
+from gi.repository import GLib
 
 from aptsources.sourceslist import SourceEntry, SourcesList
 
@@ -50,7 +50,7 @@ class AptChannelsManager(ChannelsManager):
                              self._remove_no_longer_needed_extra_channels)
         # kick off a background check for changes that may have been made
         # in the channels list
-        GObject.timeout_add_seconds(60, self._check_for_channel_updates_timer)
+        GLib.timeout_add_seconds(60, self._check_for_channel_updates_timer)
         # extra channels from e.g. external sources
         self.extra_channels = []
         self._logger = LOG
@@ -157,10 +157,10 @@ class AptChannelsManager(ChannelsManager):
         # this is expensive and does not need UI to we shove it out
         channel_update = os.path.join(
             softwarecenter.paths.datadir, "update-software-center-channels")
-        (pid, stdin, stdout, stderr) = GObject.spawn_async(
+        (pid, stdin, stdout, stderr) = GLib.spawn_async(
             [channel_update],
-            flags=GObject.SPAWN_DO_NOT_REAP_CHILD)
-        GObject.child_watch_add(
+            flags=GLib.SpawnFlags.DO_NOT_REAP_CHILD)
+        GLib.child_watch_add(GLib.PRIORITY_DEFAULT,
             pid, self._on_check_for_channel_updates_finished)
 
     def _on_check_for_channel_updates_finished(self, pid, condition):
