@@ -31,7 +31,7 @@ import threading
 
 from bsddb import db as bdb
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
 # py3 compat
 try:
@@ -174,7 +174,7 @@ class Review(object):
         self.version = ""
         self.usefulness_total = 0
         self.usefulness_favorable = 0
-        # this will be set if tryint to submit usefulness for this review
+        # this will be set if trying to submit usefulness for this review
         # failed
         self.usefulness_submit_error = False
         self.delete_error = False
@@ -204,7 +204,7 @@ class Review(object):
 
     @classmethod
     def from_piston_mini_client(cls, other):
-        """ converts the rnrclieent reviews we get into
+        """ converts the rnrclient reviews we get into
             "our" Review object (we need this as we have more
             attributes then the rnrclient review object)
         """
@@ -325,7 +325,7 @@ class ReviewLoader(GObject.GObject):
             pass
 
     def refresh_review_stats(self):
-        """ get the review statists and call callback when its there """
+        """ get the review statistics and call callback when its there """
         pass
 
     def save_review_stats_cache_file(self, nonblocking=True):
@@ -466,7 +466,7 @@ class ReviewLoader(GObject.GObject):
         pass
 
     def spawn_submit_usefulness_ui(self, review_id, is_useful, parent_xid,
-        datadir, callback):
+                                   datadir, callback):
         """Spawn a helper to submit a usefulness vote."""
         pass
 
@@ -475,7 +475,7 @@ class ReviewLoader(GObject.GObject):
         pass
 
     def spawn_modify_review_ui(self, parent_xid, iconname, datadir, review_id,
-        callback):
+                               callback):
         """Spawn a helper to modify a review."""
         pass
 
@@ -502,7 +502,7 @@ class ReviewLoaderFake(ReviewLoader):
         return random.choice(self.SUMMARIES)
 
     def get_reviews(self, application, page=1, language=None,
-        sort=0, relaxed=False):
+                    sort=0, relaxed=False):
         if not application in self._review_stats_cache:
             self.get_review_stats(application)
         stats = self._review_stats_cache[application]
@@ -554,16 +554,16 @@ class ReviewLoaderTechspeak(ReviewLoaderFake):
     LOREM = u"""This package is using cloud based technology that will
 make it suitable in a distributed environment where soup and xml-rpc
 are used. The backend is written in C++ but the frontend code will
-utilize dynamic languages lika LUA to provide a execution environment
+utilize dynamic languages like LUA to provide a execution environment
 based on JIT technology.
 
 The software in this packages has a wonderful GUI, its based on OpenGL
-but can alternative use DirectX (on plattforms were it is
+but can alternative use DirectX (on platforms were it is
 available). Dynamic shading utilizes all GPU cores and out-of-order
 thread scheduling is used to visualize the data optimally on multi
 core systems.
 
-The database support in tthis application is bleding edge. Not only
+The database support in this application is bleeding edge. Not only
 classical SQL techniques are supported but also object-relational
 models and advanced ORM technology that will do auto-lookups based on
 dynamic join/select optimizations to leverage sharded or multihosted
@@ -580,7 +580,7 @@ capacity is a function of the square root of the intermix ratio times
 the sum of the plasma injector quotient.
 
 The iApp is using the new touch UI that feels more natural then
-tranditional window based offerings. It supports a Job button that
+traditional window based offerings. It supports a Job button that
 will yell at you when pressed and a iAmCool mode where the logo of
 your new device blinks so that you attract maximum attention.
 
@@ -683,7 +683,7 @@ class ReviewLoaderNull(ReviewLoader):
         self._reviews_cache = {}
 
     def get_reviews(self, application, page=1, language=None,
-        sort=0, relaxed=False):
+                    sort=0, relaxed=False):
         self.emit("get-reviews-finished", application, [])
 
     def get_review_stats(self, application):
@@ -751,8 +751,8 @@ if __name__ == "__main__":
 
     print "\n\n"
     print "default loader, press ctrl-c for next loader"
-    context = GObject.main_context_default()
-    main = GObject.MainLoop(context)
+    context = GLib.main_context_default()
+    main = GLib.MainLoop(context)
     main.run()
 
     # default loader
