@@ -33,7 +33,7 @@ import json
 import softwarecenter.paths
 from softwarecenter.paths import PistonHelpers
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
 LOG = logging.getLogger(__name__)
 
@@ -52,8 +52,8 @@ class SpawnHelper(GObject.GObject):
         "error": (GObject.SIGNAL_RUN_LAST,
                   GObject.TYPE_NONE,
                   (str,),
-                 ),
-        }
+                  ),
+    }
 
     def __init__(self, format="pickle"):
         super(SpawnHelper, self).__init__()
@@ -93,14 +93,16 @@ class SpawnHelper(GObject.GObject):
         if "SOFTWARE_CENTER_DISABLE_SPAWN_HELPER" in os.environ:
             return
         self._cmd = cmd
-        (pid, stdin, stdout, stderr) = GObject.spawn_async(
+        (pid, stdin, stdout, stderr) = GLib.spawn_async(
             cmd, flags=GObject.SPAWN_DO_NOT_REAP_CHILD,
             standard_output=True, standard_error=True)
         LOG.debug("running: '%s' as pid: '%s'" % (cmd, pid))
-        self._child_watch = GObject.child_watch_add(
-            pid, self._helper_finished, data=(stdout, stderr))
-        self._io_watch = GObject.io_add_watch(
-            stdout, GObject.IO_IN, self._helper_io_ready, (stdout, ))
+        self._child_watch = GLib.child_watch_add(
+            pid, self._helper_finished,
+            (stdout, stderr), GLib.PRIORITY_DEFAULT)
+        self._io_watch = GLib.io_add_watch(
+            stdout, GObject.IO_IN,
+            self._helper_io_ready, (stdout, ))
 
     def _helper_finished(self, pid, status, (stdout, stderr)):
         LOG.debug("helper_finished: '%s' '%s'" % (pid, status))
@@ -119,10 +121,10 @@ class SpawnHelper(GObject.GObject):
             os.close(stderr)
         if self._io_watch:
             # remove with a delay timeout delay to ensure that any
-            # pending data is still flused
-            GObject.timeout_add(100, GObject.source_remove, self._io_watch)
+            # pending data is still flushed
+            GLib.timeout_add(100, GLib.source_remove, self._io_watch)
         if self._child_watch:
-            GObject.source_remove(self._child_watch)
+            GLib.source_remove(self._child_watch)
 
     def _helper_io_ready(self, source, condition, (stdout,)):
         # read the raw data
