@@ -28,7 +28,7 @@ import subprocess
 import string
 import imp
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
 from threading import Thread, Event
 from weblive_pristine import WebLive
@@ -108,7 +108,7 @@ class WebLiveBackend(object):
         """ Create a user on 'serverid' and start the session """
 
         # Use the boot_id to get a temporary unique identifier
-        # (till next reboot)
+        # (until next reboot)
         if os.path.exists('/proc/sys/kernel/random/boot_id'):
             uuid = open('/proc/sys/kernel/random/boot_id',
                 'r').read().strip().replace('-', '')
@@ -261,19 +261,20 @@ class WebLiveClientQTNX(WebLiveClient):
 
             self.helper_progress = 0
             qtnx_countdown()
-            GObject.timeout_add_seconds(2, qtnx_countdown)
+            GLib.timeout_add_seconds(2, qtnx_countdown)
 
         qtnx_start_timer()
 
         if wait is False:
             # Start in the background and attach a watch for when it exits
-            (self.helper_pid, stdin, stdout, stderr) = GObject.spawn_async(
+            (self.helper_pid, stdin, stdout, stderr) = GLib.spawn_async(
                 cmd, standard_input=True, standard_output=True,
                 standard_error=True, flags=GObject.SPAWN_DO_NOT_REAP_CHILD)
-            GObject.child_watch_add(self.helper_pid, self._on_qtnx_exit,
+            GLib.child_watch_add(
+                GLib.PRIORITY_DEFAULT, self.helper_pid, self._on_qtnx_exit,
                 filename)
         else:
-            # Start it and wait till it finishes
+            # Start it and wait until it finishes
             p = subprocess.Popen(cmd)
             p.wait()
 
@@ -308,7 +309,7 @@ class WebLiveClientX2GO(WebLiveClient):
         # Start in the background and attach a watch for when it exits
         cmd = [os.path.join(softwarecenter.paths.datadir,
             softwarecenter.paths.X2GO_HELPER)]
-        (self.helper_pid, stdin, stdout, stderr) = GObject.spawn_async(
+        (self.helper_pid, stdin, stdout, stderr) = GLib.spawn_async(
             cmd, standard_input=True, standard_output=True,
             standard_error=True, flags=GObject.SPAWN_DO_NOT_REAP_CHILD)
         self.helper_stdin = os.fdopen(stdin, "w")
@@ -316,11 +317,13 @@ class WebLiveClientX2GO(WebLiveClient):
         self.helper_stderr = os.fdopen(stderr)
 
         # Add a watch for when the process exits
-        GObject.child_watch_add(self.helper_pid, self._on_x2go_exit)
+        GLib.child_watch_add(
+            GLib.PRIORITY_DEFAULT, self.helper_pid, self._on_x2go_exit)
 
         # Add a watch on stdout
-        GObject.io_add_watch(self.helper_stdout, GObject.IO_IN,
-            self._on_x2go_activity)
+        channel = GLib.IOChannel.unix_new(self.helper_stdout)
+        GLib.io_add_watch(channel, GLib.PRIORITY_DEFAULT,
+                          GObject.IO_IN, self._on_x2go_activity)
 
         # Start the connection
         self.state = "connecting"
