@@ -27,14 +27,14 @@ from softwarecenter.db.application import Application
 from softwarecenter.db.pkginfo import get_pkg_info
 import softwarecenter.paths
 
-from gi.repository import GObject, Gio
+from gi.repository import GObject, Gio, GLib
 
 from softwarecenter.utils import ExecutionTime
 from softwarecenter.enums import (
     AVAILABLE_FOR_PURCHASE_MAGIC_CHANNEL_NAME,
     PkgStates,
     XapianValues
-    )
+)
 
 from softwarecenter.paths import XAPIAN_BASE_PATH_SOFTWARE_CENTER_AGENT
 from gettext import gettext as _
@@ -45,7 +45,7 @@ LOG = logging.getLogger(__name__)
 def get_reinstall_previous_purchases_query():
     """Return a query to get applications purchased
 
-    :return: a xapian query to get all the apps that are purchaed
+    :return: a xapian query to get all the apps that are purchased
     """
     # this query will give us all documents that have a purchase date != ""
     query = xapian.Query(xapian.Query.OP_VALUE_GE,
@@ -79,14 +79,14 @@ class SearchQuery(list):
     def __init__(self, query_string_or_list):
         if query_string_or_list is None:
             pass
-        # turn single querries into a single item list
+        # turn single queries into a single item list
         elif isinstance(query_string_or_list, xapian.Query):
             self.append(query_string_or_list)
         else:
             self.extend(query_string_or_list)
 
     def __eq__(self, other):
-        # turn single querries into a single item list
+        # turn single queries into a single item list
         if isinstance(other, xapian.Query):
             other = [other]
         q1 = [str(q) for q in self]
@@ -131,7 +131,7 @@ class TopRatedSorter(xapian.KeyMaker):
 class StoreDatabase(GObject.GObject):
     """thin abstraction for the xapian database with convenient functions"""
 
-    # TRANSLATORS: List of "grey-listed" words sperated with ";"
+    # TRANSLATORS: List of "grey-listed" words separated with ";"
     # Do not translate this list directly. Instead,
     # provide a list of words in your language that people are likely
     # to include in a search but that should normally be ignored in
@@ -139,7 +139,7 @@ class StoreDatabase(GObject.GObject):
     SEARCH_GREYLIST_STR = _("app;application;package;program;programme;"
                             "suite;tool")
 
-    # signal emited
+    # signal emitted
     __gsignals__ = {"reopen": (GObject.SIGNAL_RUN_FIRST,
                                GObject.TYPE_NONE,
                                ()),
@@ -196,7 +196,7 @@ class StoreDatabase(GObject.GObject):
             except:
                 LOG.exception("failed to add apt-xapian-index")
         if (self._use_agent and
-            os.path.exists(XAPIAN_BASE_PATH_SOFTWARE_CENTER_AGENT)):
+                os.path.exists(XAPIAN_BASE_PATH_SOFTWARE_CENTER_AGENT)):
             try:
                 sca = xapian.Database(XAPIAN_BASE_PATH_SOFTWARE_CENTER_AGENT)
                 xapiandb.add_database(sca)
@@ -223,7 +223,7 @@ class StoreDatabase(GObject.GObject):
 
     def open(self, pathname=None, use_axi=True, use_agent=True):
         """ open the database """
-        LOG.info("open() database: path=%s use_axi=%s "
+        LOG.debug("open() database: path=%s use_axi=%s "
                           "use_agent=%s" % (pathname, use_axi, use_agent))
         if pathname:
             self._db_pathname = pathname
@@ -265,11 +265,11 @@ class StoreDatabase(GObject.GObject):
         # we only care about the utime() update from update-a-x-i
         if not event == Gio.FileMonitorEvent.ATTRIBUTE_CHANGED:
             return
-        LOG.info("afile '%s' changed" % afile)
+        LOG.debug("afile '%s' changed" % afile)
         if self._timeout_id:
-            GObject.source_remove(self._timeout_id)
+            GLib.source_remove(self._timeout_id)
             self._timeout_id = None
-        self._timeout_id = GObject.timeout_add(500, self.reopen)
+        self._timeout_id = GLib.timeout_add(500, self.reopen)
 
     def add_database(self, database):
         self._additional_databases.append(database)
@@ -283,14 +283,14 @@ class StoreDatabase(GObject.GObject):
     def schema_version(self):
         """Return the version of the database layout
 
-           This is useful to ensure we force a rebuild if its
+           This is useful to ensure we force a rebuild if it's
            older than what we expect
         """
         return self.xapiandb.get_metadata("db-schema-version")
 
     def reopen(self):
         """ reopen the database """
-        LOG.info("reopen() database")
+        LOG.debug("reopen() database")
         self.open(use_axi=self._use_axi, use_agent=self._use_agent)
         self.emit("reopen")
 
@@ -306,7 +306,7 @@ class StoreDatabase(GObject.GObject):
         enquire = xapian.Enquire(self.xapiandb)
         query = xapian.Query()
         for pkgname in pkgnames:
-            # even on the raspbery pi this query super quick (~0.003s)
+            # even on the raspberry pi this query is super quick (~0.003s)
             with ExecutionTime("de-dup query_for_pkgnames"):
                 tmp_query = xapian.Query("AP" + pkgname)
                 enquire.set_query(tmp_query)
@@ -324,7 +324,7 @@ class StoreDatabase(GObject.GObject):
         return query
 
     def get_query_list_from_search_entry(self, search_term,
-        category_query=None):
+                                         category_query=None):
         """ get xapian.Query from a search term string and a limit the
             search to the given category
         """
@@ -417,7 +417,8 @@ class StoreDatabase(GObject.GObject):
         return self.xapian_parser.get_corrected_query_string()
 
     def get_most_popular_applications_for_mimetype(self, mimetype,
-        only_uninstalled=True, num=3):
+                                                   only_uninstalled=True,
+                                                   num=3):
         """ return a list of the most popular applications for the given
             mimetype
         """
@@ -427,7 +428,7 @@ class StoreDatabase(GObject.GObject):
         # query mimetype
         query = xapian.Query("AM%s" % mimetype)
         enquire.set_query(query)
-        # mset just needs to be "big enough""
+        # mset just needs to be "big enough"
         matches = enquire.get_mset(0, 100)
         apps = []
         for match in matches:
@@ -452,7 +453,7 @@ class StoreDatabase(GObject.GObject):
         if not summary and self._aptcache.ready:
             pkgname = self.get_pkgname(doc)
             if (pkgname in self._aptcache and
-                self._aptcache[pkgname].candidate):
+                    self._aptcache[pkgname].candidate):
                 return self._aptcache[pkgname].candidate.summary
             elif channel:
                 # FIXME: print something if available for our arch
@@ -474,7 +475,7 @@ class StoreDatabase(GObject.GObject):
         if not pkgname:
             # the doc says that get_value() is quicker than get_data()
             # so we use that if we have a updated DB, otherwise
-            # fallback to the old way (the xapian DB may not yet be rebuild)
+            # fallback to the old way (the xapian DB may not yet be rebuilt)
             if self._axi_values and "pkgname" in self._axi_values:
                 pkgname = doc.get_value(self._axi_values["pkgname"])
             else:
@@ -534,7 +535,7 @@ class StoreDatabase(GObject.GObject):
         return popcon
 
     def get_xapian_document(self, appname, pkgname):
-        """Get the machting xapian document for appname, pkgname.
+        """Get the matching xapian document for appname, pkgname.
 
         If no document is found, raise a IndexError.
 
@@ -563,7 +564,7 @@ class StoreDatabase(GObject.GObject):
         """Check if 'pkgname' is known to this database.
 
         Note that even if this function returns True, it may mean that the
-        package needs  to be purchased first or is available in a
+        package needs to be purchased first or is available in a
         not-yet-enabled source.
 
         """
@@ -595,7 +596,7 @@ class StoreDatabase(GObject.GObject):
         for m in matches:
             pkgname = self.get_pkgname(m.document)
             if (pkgname in self._aptcache and
-                self._aptcache[pkgname].is_installed):
+                    self._aptcache[pkgname].is_installed):
                 installed_purchased_packages.add(pkgname)
         return installed_purchased_packages
 
