@@ -27,7 +27,7 @@ import time
 import xapian
 
 from aptsources.sourceslist import SourceEntry
-from gi.repository import GObject
+from gi.repository import GLib
 from piston_mini_client import PistonResponseObject
 
 from softwarecenter.backend.scagent import SoftwareCenterAgent
@@ -74,12 +74,12 @@ from softwarecenter.db.pkginfo import get_pkg_info
 from softwarecenter.distro import (
     get_current_arch,
     get_foreign_architectures,
-    )
+)
 from softwarecenter.region import (
     get_region_cached,
     REGION_BLACKLIST_TAG,
     REGION_WHITELIST_TAG,
-    )
+)
 
 
 # weights for the different fields
@@ -148,6 +148,7 @@ class AppInfoParserBase(object):
         AppInfoFields.CHANNEL: XapianValues.ARCHIVE_CHANNEL,
         AppInfoFields.DEB_LINE: XapianValues.ARCHIVE_DEB_LINE,
         AppInfoFields.DESCRIPTION: XapianValues.SC_DESCRIPTION,
+        AppInfoFields.DOWNLOAD_SIZE: XapianValues.DOWNLOAD_SIZE,
         AppInfoFields.CATEGORIES: XapianValues.CATEGORIES,
         AppInfoFields.CURRENCY: XapianValues.CURRENCY,
         AppInfoFields.DATE_PUBLISHED: XapianValues.DATE_PUBLISHED,
@@ -209,7 +210,7 @@ class AppInfoParserBase(object):
     }
 
     # a mapping that the subclasses override, it defines the mapping
-    # from the Application Info Fileds to the "native" keywords used
+    # from the Application Info Fields to the "native" keywords used
     # by the various subclasses, e.g. "
     #   X-AppInstall-Channel for desktop files
     # or
@@ -379,10 +380,16 @@ class AppInfoParserBase(object):
         if price:
             # this is a commercial app, indicate it in the component value
             doc.add_value(XapianValues.ARCHIVE_SECTION, "commercial")
-            # this is hardcoded to US dollar for now, but if the server
+            # this is hard-coded to US dollar for now, but if the server
             # ever changes we can update
             doc.add_value(XapianValues.CURRENCY, "US$")
 
+        # add donwload size as string (its send as int)
+        download_size = self.get_value(AppInfoFields.DOWNLOAD_SIZE)
+        if download_size is not None:
+            doc.add_value(XapianValues.DOWNLOAD_SIZE,
+                          xapian.sortable_serialise((download_size)))
+
         # write out categories
         for cat in self.get_categories():
             doc.add_term("AC" + cat.lower())
@@ -412,14 +419,15 @@ class AppInfoParserBase(object):
                 countrycode = region["countrycode"].lower()
                 # blacklist
                 if "%s%s" % (REGION_BLACKLIST_TAG, countrycode) in tags:
-                    LOG.info("%r.make_doc: skipping region restricted app %r "
+                    LOG.debug("%r.make_doc: skipping region restricted app %r "
                              "(blacklisted)", self.__class__.__name__, name)
                     return
                 # whitelist
                 for tag in tags:
+                    s = "%s%s" % (REGION_WHITELIST_TAG, countrycode)
                     if (tag.startswith(REGION_WHITELIST_TAG) and not
-                        "%s%s" % (REGION_WHITELIST_TAG, countrycode) in tag):
-                        LOG.info("%r.make_doc: skipping region restricted "
+                            s in tag):
+                        LOG.debug("%r.make_doc: skipping region restricted "
                                  "app %r (region not whitelisted)",
                                  self.__class__.__name__, name)
                         return
@@ -480,13 +488,13 @@ class AppInfoParserBase(object):
             WEIGHT_APT_PKGNAME)
 
         # now add search data from the desktop file
-        for weigth, key in [('GENERICNAME', AppInfoFields.GENERIC_NAME),
+        for weight, key in [('GENERICNAME', AppInfoFields.GENERIC_NAME),
                             ('COMMENT', AppInfoFields.SUMMARY),
                             ('DESCRIPTION', AppInfoFields.DESCRIPTION)]:
             s = self.get_value(key)
             if not s:
                 continue
-            k = "WEIGHT_DESKTOP_" + weigth
+            k = "WEIGHT_DESKTOP_" + weight
             w = globals().get(k)
             if w is None:
                 LOG.debug("%r.index_app_info: WEIGHT %r not found",
@@ -534,6 +542,7 @@ class SCAApplicationParser(AppInfoParserBase):
         AppInfoFields.PACKAGE: 'package_name',
         AppInfoFields.PRICE: 'price',
         AppInfoFields.DESCRIPTION: 'description',
+        AppInfoFields.DOWNLOAD_SIZE: 'binary_filesize',
         AppInfoFields.SUPPORTED_DISTROS: 'series',
         AppInfoFields.SCREENSHOT_URLS: 'screenshot_url',
         AppInfoFields.SUMMARY: 'comment',
@@ -562,7 +571,7 @@ class SCAApplicationParser(AppInfoParserBase):
         # the thumbnail and scale it for display, this is done because
         # we no longer keep thumbnail versions of screenshots on the server
         if (hasattr(self.sca_application, "screenshot_url") and
-            not hasattr(self.sca_application, "thumbnail_url")):
+                not hasattr(self.sca_application, "thumbnail_url")):
             self.sca_application.thumbnail_url = \
                 self.sca_application.screenshot_url
         if hasattr(self.sca_application, "description"):
@@ -570,7 +579,7 @@ class SCAApplicationParser(AppInfoParserBase):
             self.sca_application.comment = comment.strip()
             self.sca_application.description = desc.strip()
 
-        # debtags is send as a list, but we need it as a comma seperated string
+        # debtags is send as a list, but we need it as a comma separated string
         debtags = getattr(self.sca_application, "debtags", [])
         self.sca_application.tags = ",".join(debtags)
 
@@ -604,7 +613,7 @@ class SCAApplicationParser(AppInfoParserBase):
 
         # support multiple screenshots
         if hasattr(self.sca_application, "screenshot_urls"):
-            # ensure to html-quote "," as this is also our seperator
+            # ensure to html-quote "," as this is also our separator
             s = ",".join([url.replace(",", "%2C")
                           for url in self.sca_application.screenshot_urls])
             self.sca_application.screenshot_url = s
@@ -631,7 +640,7 @@ class SCAApplicationParser(AppInfoParserBase):
 
 
 class SCAPurchasedApplicationParser(SCAApplicationParser):
-    """A purchased application hase some additional subscription attributes."""
+    """A purchased application has some additional subscription attributes."""
 
     SUBSCRIPTION_MAPPING = {
         # this key can be used to get the original deb_line that the
@@ -792,6 +801,7 @@ class DesktopTagSectionParser(AppInfoParserBase):
         AppInfoFields.DATE_PUBLISHED: 'X-AppInstall-Date-Published',
         AppInfoFields.DEB_LINE: 'X-AppInstall-Deb-Line',
         AppInfoFields.DESCRIPTION: 'X-AppInstall-Description',
+        AppInfoFields.DOWNLOAD_SIZE: 'X-AppInstall-DownloadSize',
         AppInfoFields.GENERIC_NAME: 'GenericName',
         AppInfoFields.GETTEXT_DOMAIN: 'X-Ubuntu-Gettext-Domain',
         AppInfoFields.ICON: 'Icon',
@@ -951,7 +961,7 @@ def update_from_var_lib_apt_lists(db, cache, listsdir=None):
         return False
     if not listsdir:
         listsdir = apt_pkg.config.find_dir("Dir::State::lists")
-    context = GObject.main_context_default()
+    context = GLib.main_context_default()
     for appinfo in glob("%s/*AppInfo" % listsdir):
         LOG.debug("processing %r", appinfo)
         # process events
@@ -981,7 +991,7 @@ def update_from_single_appstream_file(db, cache, filename):
 def update_from_appstream_xml(db, cache, xmldir=None):
     if not xmldir:
         xmldir = softwarecenter.paths.APPSTREAM_XML_PATH
-    context = GObject.main_context_default()
+    context = GLib.main_context_default()
 
     if os.path.isfile(xmldir):
         update_from_single_appstream_file(db, cache, xmldir)
@@ -1000,7 +1010,7 @@ def update_from_app_install_data(db, cache, datadir=None):
     """ index the desktop files in $datadir/desktop/*.desktop """
     if not datadir:
         datadir = softwarecenter.paths.APP_INSTALL_DESKTOP_PATH
-    context = GObject.main_context_default()
+    context = GLib.main_context_default()
     for desktopf in glob(datadir + "/*.desktop"):
         LOG.debug("processing %r", desktopf)
         # process events
@@ -1044,8 +1054,8 @@ def update_from_software_center_agent(db, cache, ignore_cache=False,
         sca.good_data = False
         loop.quit()
 
-    context = GObject.main_context_default()
-    loop = GObject.MainLoop(context)
+    context = GLib.main_context_default()
+    loop = GLib.MainLoop(context)
 
     sca = SoftwareCenterAgent(ignore_cache)
     sca.connect("available", _available_cb)
@@ -1083,7 +1093,7 @@ def update_from_software_center_agent(db, cache, ignore_cache=False,
     # process data
     for entry in sca.available:
 
-        # do not add stuff here thats already purchased to avoid duplication
+        # do not add stuff here that's already purchased to avoid duplication
         if entry.package_name in available_for_me_pkgnames:
             continue
 
@@ -1103,7 +1113,8 @@ def update_from_software_center_agent(db, cache, ignore_cache=False,
     return sca.good_data
 
 
-def rebuild_database(pathname, debian_sources=True, appstream_sources=False):
+def rebuild_database(pathname, debian_sources=True, appstream_sources=False,
+                     appinfo_dir=None):
     #cache = apt.Cache(memonly=True)
     cache = get_pkg_info()
     cache.open()
@@ -1140,7 +1151,7 @@ def rebuild_database(pathname, debian_sources=True, appstream_sources=False):
     db = xapian.WritableDatabase(rebuild_path, xapian.DB_CREATE_OR_OVERWRITE)
 
     if debian_sources:
-        update(db, cache)
+        update(db, cache, appinfo_dir)
     if appstream_sources:
         if os.path.exists('./data/app-stream/appdata.xml'):
             update_from_appstream_xml(db, cache,
@@ -1148,7 +1159,7 @@ def rebuild_database(pathname, debian_sources=True, appstream_sources=False):
         else:
             update_from_appstream_xml(db, cache)
 
-    # write the database version into the filep
+    # write the database version into the file
     db.set_metadata("db-schema-version", DB_SCHEMA_VERSION)
     # update the mo file stamp for the langpack checks
     mofile = gettext.find("app-install-data")
