@@ -19,7 +19,7 @@
 import logging
 import os
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
 import softwarecenter.paths
 
@@ -38,10 +38,11 @@ def run_software_center_agent(db):
     # run the update
     sc_agent_update = os.path.join(
         softwarecenter.paths.datadir, "update-software-center-agent")
-    (pid, stdin, stdout, stderr) = GObject.spawn_async(
+    (pid, stdin, stdout, stderr) = GLib.spawn_async(
         [sc_agent_update, "--datadir", softwarecenter.paths.datadir],
         flags=GObject.SPAWN_DO_NOT_REAP_CHILD)
-    GObject.child_watch_add(pid, _on_update_software_center_agent_finished)
+    GLib.child_watch_add(
+        GLib.PRIORITY_DEFAULT, pid, _on_update_software_center_agent_finished)
 
 
 def get_installed_apps_list(db):
@@ -51,7 +52,7 @@ def get_installed_apps_list(db):
         if db.get_appname(doc):
             pkgname = db.get_pkgname(doc)
             if (pkgname in db._aptcache and
-                db._aptcache[pkgname].is_installed):
+                    db._aptcache[pkgname].is_installed):
                 apps.add(db.get_application(doc))
     return apps
 
