@@ -390,20 +390,20 @@ class PasswordLabeledEntryTestCase(LabeledEntryTestCase):
         self.entry.is_password = True
 
     def test_password_fields_are_visible_at_startup(self):
-        """Password entrys show the helping text at startup."""
+        """Password entries show the helping text at startup."""
         self.assertTrue(self.entry.get_visibility(),
                         'Password entry should be visible at start up.')
 
     def test_password_field_is_visible_if_no_input_and_focus_out(self):
         """Password entry show the label when focus out."""
-        self.grab_focus()  # user cliked or TAB'd to the entry
+        self.grab_focus()  # user clicked or TAB'd to the entry
         self.grab_focus(focus_in=False)  # loose focus
         self.assertTrue(self.entry.get_visibility(),
                         'Entry should be visible when focus out and no input.')
 
     def test_password_fields_are_not_visible_when_editing(self):
-        """Password entrys show the hidden chars instead of the password."""
-        self.grab_focus()  # user cliked or TAB'd to the entry
+        """Password entries show the hidden chars instead of the password."""
+        self.grab_focus()  # user clicked or TAB'd to the entry
         self.assertFalse(self.entry.get_visibility(),
                          'Entry should not be visible when editing.')
 
@@ -878,7 +878,7 @@ class EnterDetailsTestCase(UbuntuSSOClientTestCase):
         self.assertTrue(self._called)
 
     def test_user_and_pass_are_cached(self):
-        """Username and password are temporarly cached for further use."""
+        """Username and password are temporarily cached for further use."""
         self.click_join_with_valid_data()
         self.assertEqual(self.ui.user_email, EMAIL)
         self.assertEqual(self.ui.user_password, PASSWORD)
@@ -1045,7 +1045,7 @@ class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
         self.assertEqual(self._called, ((), {}))
 
     def test_navigation_requested_ignores_for_none(self):
-        """The navigation request is ignoref the request if params are None."""
+        """The navigation request is ignored the request if params are None."""
         kwargs = dict(browser=None, frame=None, request=None,
                       action=None, decision=None)
         self.ui.on_tc_browser_navigation_requested(**kwargs)
@@ -1584,7 +1584,7 @@ class LoginTestCase(UbuntuSSOClientTestCase):
         self.assertTrue(self._called)
 
     def test_user_and_pass_are_cached(self):
-        """Username and password are temporarly cached for further use."""
+        """Username and password are temporarily cached for further use."""
         self.click_connect_with_valid_data()
         self.assertEqual(self.ui.user_email, EMAIL)
         self.assertEqual(self.ui.user_password, PASSWORD)
@@ -1749,7 +1749,7 @@ class ResetPasswordTestCase(UbuntuSSOClientTestCase):
         self.assertEqual(actual.decode('utf8'), gui.RESET_PASSWORD)
 
     def test_on_password_reset_error_shows_login_page(self):
-        """When reset token wasn't successfuly sent the login page is shown."""
+        """When reset token wasn't successfully sent, login page is shown."""
         self.ui.on_password_reset_error(app_name=APP_NAME, error=self.error)
         self.assert_correct_label_warning(self.ui.warning_label,
                                           UNKNOWN_ERROR)
@@ -1862,7 +1862,7 @@ class SetNewPasswordTestCase(UbuntuSSOClientTestCase):
             APP_NAME, EMAIL, RESET_PASSWORD_TOKEN, PASSWORD)
 
     def test_on_password_changed_shows_login_page(self):
-        """When password was successfuly changed the login page is shown."""
+        """When password was successfully changed the login page is shown."""
         self.ui.on_password_changed(app_name=APP_NAME, email=EMAIL)
         self.assert_correct_label_warning(self.ui.warning_label,
                                           gui.PASSWORD_CHANGED)
@@ -1887,7 +1887,7 @@ class SetNewPasswordTestCase(UbuntuSSOClientTestCase):
         self.assert_correct_label_warning(self.ui.warning_label, expected)
 
     def test_ok_button_does_nothing_if_clicked_but_disabled(self):
-        """The new passwrd can only be set if the button is sensitive."""
+        """The new password can only be set if the button is sensitive."""
         self.patch(self.ui.reset_code_entry, 'get_text', self._set_called)
 
         self.ui.set_new_password_ok_button.set_sensitive(False)
@@ -1973,7 +1973,7 @@ class SignalsTestCase(UbuntuSSOClientTestCase):
     """Test suite for the backend signals."""
 
     def test_all_the_signals_are_listed(self):
-        """All the backend signals are listed to be binded."""
+        """All the backend signals are listed to be bound."""
         for sig in ('CaptchaGenerated', 'CaptchaGenerationError',
                     'UserRegistered', 'UserRegistrationError',
                     'LoggedIn', 'LoginError', 'UserNotValidated',
@@ -2195,7 +2195,7 @@ class ReturnCodeTestCase(UbuntuSSOClientTestCase):
     def test_login_success_even_if_prior_login_error(self):
         """Only one callback is called with the final outcome.
 
-        When the user successfully logins, LOGIN_SUCCESS is called even if
+        When the user successfully logs in, LOGIN_SUCCESS is called even if
         there were errors before.
 
         """
