@@ -19,6 +19,7 @@
 
 # order is import here, otherwise test/gtk3/test_purchase.py is unhappy
 from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Gtk
 
 import atexit
@@ -54,7 +55,7 @@ from softwarecenter.db.application import Application
 from softwarecenter.db import (
     DebFileApplication,
     DebFileOpenError,
-    )
+)
 from softwarecenter.db.utils import run_software_center_agent
 from softwarecenter.i18n import init_locale
 
@@ -89,7 +90,7 @@ from softwarecenter.version import VERSION
 from softwarecenter.db.database import (
     StoreDatabase,
     get_reinstall_previous_purchases_query,
-    )
+)
 try:
     from aptd_gtk3 import InstallBackendUI
     InstallBackendUI  # pyflakes
@@ -111,11 +112,11 @@ from softwarecenter.ui.gtk3.panes.pendingpane import PendingPane
 from softwarecenter.ui.gtk3.session.appmanager import (
     ApplicationManager,
     get_appmanager,
-    )
+)
 from softwarecenter.ui.gtk3.session.viewmanager import (
     ViewManager,
     get_viewmanager,
-    )
+)
 from softwarecenter.ui.gtk3.widgets.recommendations import (
     RecommendationsOptInDialog)
 
@@ -258,7 +259,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     START_DBUS = True
 
     def __init__(self, options, args=None):
-        self.dbusControler = None
+        self.dbusController = None
         if self.START_DBUS:
             # setup dbus and exit if there is another instance already running
             self.setup_dbus_or_bring_other_instance_to_front(args)
@@ -478,14 +479,14 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             self.menu_file.remove(self.menuitem_reinstall_purchases)
         else:
             # running the agent will trigger a db reload so we do it later
-            GObject.timeout_add_seconds(3, self._run_software_center_agent)
+            GLib.timeout_add_seconds(3, self._run_software_center_agent)
 
         # keep the cache clean
-        GObject.timeout_add_seconds(15, self._run_expunge_cache_helper)
+        GLib.timeout_add_seconds(15, self._run_expunge_cache_helper)
 
         # check to see if a new recommendations profile upload is
         # needed and upload if necessary
-        GObject.timeout_add_seconds(45, self._upload_recommendations_profile)
+        GLib.timeout_add_seconds(45, self._upload_recommendations_profile)
 
         # TODO: Remove the following two lines once we have remove repository
         #       support in aptdaemon (see LP: #723911)
@@ -511,7 +512,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         """ helper that expires the piston-mini-client cache """
         sc_expunge_cache = os.path.join(
             self.datadir, "expunge-cache.py")
-        (pid, stdin, stdout, stderr) = GObject.spawn_async(
+        (pid, stdin, stdout, stderr) = GLib.spawn_async(
             [sc_expunge_cache,
              "--by-unsuccessful-http-states",
              softwarecenter.paths.SOFTWARE_CENTER_CACHE_DIR,
@@ -609,20 +610,23 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         self.app_manager.destroy()
         self.view_manager.destroy()
 
-        if self.dbusControler is not None:
+        if self.dbusController is not None:
             # ensure that the dbus controller is really gone
-            self.dbusControler.stop()
+            self.dbusController.stop()
 
     def close_app(self):
         """ perform tasks like save-state etc when the application is
             exited
         """
         # this may happen during the early initialization
-        # when "app.run()" was called but has not finished seting up the
+        # when "app.run()" was called but has not finished setting up the
         # stuff yet, in this case its ok to just exit
         if Gtk.main_level() == 0:
-            LOG.info("closing before the regular main loop was run")
+            LOG.debug("closing before the regular main loop was run")
             sys.exit(0)
+        # hide the main window early even if saving the state etc takes
+        # a wee bit
+        self.window_main.hide()
         self.save_state()
         self.destroy()
 
@@ -632,7 +636,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             Gtk.main_quit()
         except:
             LOG.exception("Gtk.main_quit failed")
-        # exit here explictely to ensure that no further gtk event loops or
+        # exit here explicitly to ensure that no further gtk event loops or
         # threads run and cause havoc on exit (LP: #914393)
         sys.exit(0)
 
@@ -642,55 +646,55 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
         # close
         if ((event.keyval == Gdk.keyval_from_name("w") or
-             event.keyval == Gdk.keyval_from_name("q")) and
-            event.state == Gdk.ModifierType.CONTROL_MASK):
+                event.keyval == Gdk.keyval_from_name("q")) and
+                event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_close.activate()
 
         # undo/redo
         if (event.keyval == Gdk.keyval_from_name("z") and
-            event.state == Gdk.ModifierType.CONTROL_MASK):
+                event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_edit.activate()
             if self.menuitem_undo.get_sensitive():
                 self.menuitem_undo.activate()
 
         if (event.keyval == Gdk.keyval_from_name("Z") and
-            event.state == (Gdk.ModifierType.SHIFT_MASK |
-            Gdk.ModifierType.CONTROL_MASK)):
+                event.state == (Gdk.ModifierType.SHIFT_MASK |
+                                Gdk.ModifierType.CONTROL_MASK)):
             self.menuitem_edit.activate()
             if self.menuitem_redo.get_sensitive():
                 self.menuitem_redo.activate()
 
         # cut/copy/paste
         if (event.keyval == Gdk.keyval_from_name("x") and
-            event.state == Gdk.ModifierType.CONTROL_MASK):
+                event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_edit.activate()
             if self.menuitem_cut.get_sensitive():
                 self.menuitem_cut.activate()
 
         if (event.keyval == Gdk.keyval_from_name("c") and
-            event.state == Gdk.ModifierType.CONTROL_MASK):
+                event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_edit.activate()
             if self.menuitem_copy.get_sensitive():
                 self.menuitem_copy.activate()
 
         # copy web link
         if (event.keyval == Gdk.keyval_from_name("C") and
-            event.state == (Gdk.ModifierType.SHIFT_MASK |
-            Gdk.ModifierType.CONTROL_MASK)):
+                event.state == (Gdk.ModifierType.SHIFT_MASK |
+                                Gdk.ModifierType.CONTROL_MASK)):
             self.menuitem_edit.activate()
             if self.menuitem_copy_web_link.get_sensitive():
                 self.menuitem_copy_web_link.activate()
 
         # select all
         if (event.keyval == Gdk.keyval_from_name("a") and
-            event.state == Gdk.ModifierType.CONTROL_MASK):
+                event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_edit.activate()
             if self.menuitem_select_all.get_sensitive():
                 self.menuitem_select_all.activate()
 
         # search
         if (event.keyval == Gdk.keyval_from_name("f") and
-            event.state == Gdk.ModifierType.CONTROL_MASK):
+                event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_edit.activate()
             if self.menuitem_search.get_sensitive():
                 self.menuitem_search.activate()
@@ -698,9 +702,9 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         # back
         if ((event.keyval == Gdk.keyval_from_name("bracketleft") and
              event.state == Gdk.ModifierType.CONTROL_MASK) or
-            ((event.keyval == Gdk.keyval_from_name("Left") or
-              event.keyval == Gdk.keyval_from_name("KP_Left")) and
-             event.state == Gdk.ModifierType.MOD1_MASK)):
+                ((event.keyval == Gdk.keyval_from_name("Left") or
+                  event.keyval == Gdk.keyval_from_name("KP_Left")) and
+                 event.state == Gdk.ModifierType.MOD1_MASK)):
             # using the backspace key to navigate back has been disabled as it
             # has started to show dodgy side effects which I can't figure how
             # to deal with
@@ -711,9 +715,9 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         # forward
         if ((event.keyval == Gdk.keyval_from_name("bracketright") and
              event.state == Gdk.ModifierType.CONTROL_MASK) or
-            ((event.keyval == Gdk.keyval_from_name("Right") or
-              event.keyval == Gdk.keyval_from_name("KP_Right")) and
-             event.state == Gdk.ModifierType.MOD1_MASK)):
+                ((event.keyval == Gdk.keyval_from_name("Right") or
+                  event.keyval == Gdk.keyval_from_name("KP_Right")) and
+                 event.state == Gdk.ModifierType.MOD1_MASK)):
             self.menuitem_view.activate()
             if self.menuitem_go_forward.get_sensitive():
                 self.menuitem_go_forward.activate()
@@ -766,7 +770,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
         # wait for the cache to become ready (if needed)
         if not self.cache.ready:
-            GObject.timeout_add(
+            GLib.timeout_add(
                 100, lambda: self.on_menu_file_activate(menuitem))
             return False
 
@@ -783,10 +787,10 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             pkg_state = appdetails.pkg_state
             error = appdetails.error
         if (app.pkgname in
-            self.active_pane.app_view.tree_view._action_block_list):
+                self.active_pane.app_view.tree_view._action_block_list):
             return False
         elif (pkg_state == PkgStates.UPGRADABLE or
-            pkg_state == PkgStates.REINSTALLABLE and not error):
+                  pkg_state == PkgStates.REINSTALLABLE and not error):
             self.menuitem_install.set_sensitive(True)
             self.menuitem_remove.set_sensitive(True)
         elif pkg_state == PkgStates.INSTALLED:
@@ -794,17 +798,17 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         elif pkg_state == PkgStates.UNINSTALLED and not error:
             self.menuitem_install.set_sensitive(True)
         elif (not pkg_state and
-              not self.active_pane.is_category_view_showing() and
-              app.pkgname in self.cache and
-              not app.pkgname in
-              self.active_pane.app_view.tree_view._action_block_list and
-              not error):
+                  not self.active_pane.is_category_view_showing() and
+                  app.pkgname in self.cache and
+                  not app.pkgname in
+                  self.active_pane.app_view.tree_view._action_block_list and
+                  not error):
             # when does this happen?
             pkg = self.cache[app.pkgname]
             installed = bool(pkg.installed)
             self.menuitem_install.set_sensitive(not installed)
             self.menuitem_remove.set_sensitive(installed)
-        # return False to ensure that a possible GObject.timeout_add ends
+        # return False to ensure that a possible GLib.timeout_add ends
         return False
 
     def _on_reinstall_purchased_login(self, sso, oauth_result):
@@ -951,8 +955,8 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         self.active_pane = vm.get_view_widget(vm.get_active_view())
 
         if (self.active_pane and
-            self.active_pane.searchentry and
-            self.active_pane.searchentry.get_visible()):
+                self.active_pane.searchentry and
+                self.active_pane.searchentry.get_visible()):
             # undo, redo, cut, copy, paste, delete, select_all sensitive
             # if searchentry is focused (and other more specific conditions)
             if self.active_pane.searchentry.is_focus():
@@ -980,7 +984,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
         # details view
         if (self.active_pane and
-            self.active_pane.is_app_details_view_showing()):
+                self.active_pane.is_app_details_view_showing()):
 
             self.menuitem_select_all.set_sensitive(True)
             desc = self.active_pane.app_details_view.desc
@@ -999,10 +1003,8 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
     def on_menuitem_copy_activate(self, menuitem):
         if (self.active_pane and
-            self.active_pane.is_app_details_view_showing()):
-
+                self.active_pane.is_app_details_view_showing()):
             self.active_pane.app_details_view.desc.copy_clipboard()
-
         elif self.active_pane:
             self.active_pane.searchentry.copy_clipboard()
 
@@ -1014,11 +1016,9 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
     def on_menuitem_select_all_activate(self, menuitem):
         if (self.active_pane and
-            self.active_pane.is_app_details_view_showing()):
-
+                self.active_pane.is_app_details_view_showing()):
             self.active_pane.app_details_view.desc.select_all()
             self.active_pane.app_details_view.desc.grab_focus()
-
         elif self.active_pane:
             self.active_pane.searchentry.select_region(0, -1)
 
@@ -1048,7 +1048,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
              "-n",
              "-t", str(xid)])
         # Monitor the subprocess regularly
-        GObject.timeout_add(100, self._poll_software_sources_subprocess, p)
+        GLib.timeout_add(100, self._poll_software_sources_subprocess, p)
 
     def _poll_software_sources_subprocess(self, popen):
         ret = popen.poll()
@@ -1081,11 +1081,10 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         # get our active pane
         self.active_pane = vm.get_view_widget(vm.get_active_view())
         if (self.active_pane and
-            self.active_pane == self.available_pane or
-            self.active_pane == self.installed_pane):
+                self.active_pane == self.available_pane or
+                self.active_pane == self.installed_pane):
             self.menuitem_view_all.set_sensitive(True)
             self.menuitem_view_supported_only.set_sensitive(True)
-
             from softwarecenter.db.appfilter import get_global_filter
             supported_only = get_global_filter().supported_only
             self.menuitem_view_all.set_active(not supported_only)
@@ -1145,7 +1144,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         vm.nav_back()
 
     def on_navhistory_forward_action_activate(self,
-        navhistory_forward_action=None):
+                                              navhistory_forward_action=None):
         vm = get_viewmanager()
         vm.nav_forward()
 
@@ -1160,7 +1159,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
     def on_menuitem_help_activate(self, menuitem):
         # run browser
-        (pid, stdin, stdout, stderr) = GObject.spawn_async(
+        (pid, stdin, stdout, stderr) = GLib.spawn_async(
             ["yelp", "ghelp:software-center"], flags=GObject.SPAWN_SEARCH_PATH)
 
     def on_menuitem_tos_activate(self, menuitem):
@@ -1172,7 +1171,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     def _ask_and_repair_broken_cache(self):
         # wait until the window window is available
         if self.window_main.props.visible is False:
-            GObject.timeout_add_seconds(1, self._ask_and_repair_broken_cache)
+            GLib.timeout_add_seconds(1, self._ask_and_repair_broken_cache)
             return
         if dialogs.confirm_repair_broken_cache(self.window_main,
                                                       self.datadir):
@@ -1278,7 +1277,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
                 sys.exit()
         except dbus.DBusException:
             bus_name = dbus.service.BusName('com.ubuntu.Softwarecenter', bus)
-            self.dbusControler = SoftwarecenterDbusController(self, bus_name)
+            self.dbusController = SoftwarecenterDbusController(self, bus_name)
 
     @wait_for_apt_cache_ready
     def show_app(self, app):
@@ -1299,7 +1298,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     def show_available_packages(self, packages):
         """ Show packages given as arguments in the available_pane
             If the list of packages is only one element long show that,
-            otherwise turn it into a comma seperated search
+            otherwise turn it into a comma separated search
         """
         try:
             search_text, app = parse_packages_args(packages)
@@ -1311,8 +1310,8 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
                           _("The file “%s” could not be opened.") % e.path)
             search_text = app = None
 
-        LOG.info('show_available_packages: search_text is %r, app is %r.',
-                 search_text, app)
+        LOG.debug('show_available_packages: search_text is %r, app is %r.',
+                  search_text, app)
 
         if search_text:
             self.available_pane.init_view()
@@ -1342,7 +1341,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
     def save_state(self):
         LOG.debug("save_state")
-        # this happens on a delete event, we explicitely save_state() there
+        # this happens on a delete event, we explicitly save_state() there
         window = self.window_main.get_window()
         if window is None:
             return
@@ -1373,7 +1372,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         self.window_main.show_all()
 
         # delay cache open
-        GObject.timeout_add(1, self.cache.open)
+        GLib.timeout_add(1, self.cache.open)
 
         # support both "pkg1 pkg" and "pkg1,pkg2" (and pkg1,pkg2 pkg3)
         if args:
