@@ -19,6 +19,7 @@
 import gettext
 from gi.repository import GObject
 from gi.repository import Gtk
+from gi.repository import GLib
 import logging
 import xapian
 import os
@@ -75,7 +76,7 @@ class AvailablePane(SoftwarePane):
                  'list',
                  'details',
                  'purchase',
-                )
+                 )
         # actual page id's
         (LOBBY,
          SUBCATEGORY,
@@ -230,7 +231,7 @@ class AvailablePane(SoftwarePane):
         self.hide_appview_spinner()
 
         # consider the view initialized here already as display_page()
-        # may run into a endless recurison otherwise (it will call init_view())
+        # may run into a endless recursion otherwise (it will call init_view())
         # again (LP: #851671)
         self.view_initialized = True
 
@@ -285,7 +286,7 @@ class AvailablePane(SoftwarePane):
 
     def get_query(self):
         """helper that gets the query for the current category/search mode"""
-        # NoDisplay is a specal case
+        # NoDisplay is a special case
         if self._in_no_display_category():
             return xapian.Query()
         # get current sub-category (or category, but sub-category wins)
@@ -317,12 +318,12 @@ class AvailablePane(SoftwarePane):
         line2 = None
         if channel is not None:
             name = channel.display_name or channel.name
-            line1 = GObject.markup_escape_text(name)
+            line1 = GLib.markup_escape_text(name)
         elif subcategory is not None:
-            line1 = GObject.markup_escape_text(category.name)
-            line2 = GObject.markup_escape_text(subcategory.name)
+            line1 = GLib.markup_escape_text(category.name)
+            line2 = GLib.markup_escape_text(subcategory.name)
         elif category is not None:
-            line1 = GObject.markup_escape_text(category.name)
+            line1 = GLib.markup_escape_text(category.name)
         else:
             line1 = _("All Software")
         return line1, line2
@@ -432,8 +433,8 @@ class AvailablePane(SoftwarePane):
         # see LP: #913756), also, don't add the item if NoDisplay is
         # specified (see LP: #1006483)
         if (os.path.exists(installed_desktop_file_path) and
-            (not get_exec_line_from_desktop(installed_desktop_file_path) or
-            is_no_display_desktop_file(installed_desktop_file_path))):
+                (not get_exec_line_from_desktop(installed_desktop_file_path) or
+                 is_no_display_desktop_file(installed_desktop_file_path))):
             return
 
         # now gather up the unity launcher info items and send the app to the
@@ -503,8 +504,8 @@ class AvailablePane(SoftwarePane):
             for doc in self.enquirer.get_documents():
                 pkgname = self.db.get_pkgname(doc)
                 if (pkgname in self.cache and
-                    not self.cache[pkgname].is_installed and
-                    not len(self.backend.pending_transactions) > 0):
+                        not self.cache[pkgname].is_installed and
+                        not len(self.backend.pending_transactions) > 0):
                     app = Application(pkgname=pkgname)
                     installable.append(app)
             button_text = gettext.ngettext(
@@ -537,8 +538,8 @@ class AvailablePane(SoftwarePane):
         for doc in self.enquirer.get_documents():
             pkgname = self.db.get_pkgname(doc)
             if (pkgname in self.cache and
-                not self.cache[pkgname].is_installed and
-                pkgname not in self.backend.pending_transactions):
+                    not self.cache[pkgname].is_installed and
+                    pkgname not in self.backend.pending_transactions):
                 apps.append(self.db.get_application(doc))
                 # add iconnames
                 iconnames.append(self.db.get_iconname(doc))
@@ -664,7 +665,7 @@ class AvailablePane(SoftwarePane):
 
     def display_search_page(self, view_state):
         new_text = view_state.search_term
-        # DTRT if the search is reseted
+        # DTRT if the search is reset
         if not new_text:
             self._clear_search()
         else:
@@ -804,13 +805,13 @@ class AvailablePane(SoftwarePane):
             self.state.filter = AppFilter(self.db, self.cache)
 
         if (category and category.flags and
-            'available-only' in category.flags):
+                'available-only' in category.flags):
             self.state.filter.set_available_only(True)
         else:
             self.state.filter.set_available_only(False)
 
         if (category and category.flags and
-            'not-installed-only' in category.flags):
+                'not-installed-only' in category.flags):
             self.state.filter.set_not_installed_only(True)
         else:
             self.state.filter.set_not_installed_only(False)
