@@ -22,7 +22,7 @@
 
 import gi
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, GObject, Pango
+from gi.repository import Gtk, GObject, Pango, GLib
 import datetime
 import logging
 
@@ -36,22 +36,19 @@ from softwarecenter.utils import (
     upstream_version_compare,
     upstream_version,
     utf8,
-    )
-
-
+)
 from softwarecenter.i18n import (
     get_languages,
     langcode_to_name,
-    )
-
+)
 from softwarecenter.netstatus import (
     network_state_is_connected,
     get_network_watcher,
-    )
+)
 from softwarecenter.enums import (
     PkgStates,
     ReviewSortMethods,
-    )
+)
 
 from softwarecenter.backend.reviews import UsefulnessCache
 
@@ -292,8 +289,8 @@ class UIReviewsList(Gtk.VBox):
         else:
             # no reviews, either offer to write one or show "none"
             if (self.get_active_review_language() != 'any' and
-                self.global_review_stats and
-                self.global_review_stats.ratings_total > 0):
+                    self.global_review_stats and
+                    self.global_review_stats.ratings_total > 0):
                 self.vbox.pack_start(NoReviewRelaxLanguage(), True, True, 0)
             elif is_installed and is_connected:
                 self._be_the_first_to_review()
@@ -316,7 +313,7 @@ class UIReviewsList(Gtk.VBox):
         self._on_network_state_change()
 
     def _on_more_reviews_clicked(self, button):
-        # remove buttn and emit signal
+        # remove button and emit signal
         self.vbox.remove(button)
         self.emit("more-reviews-clicked")
 
@@ -483,13 +480,13 @@ class UIReview(Gtk.VBox):
             reviews.emit("submit-usefulness", self.id, is_useful)
 
     def _on_error_acknowledged(self, button, current_user_reviewer,
-        useful_total, useful_favorable):
+                               useful_total, useful_favorable):
         self.usefulness_error = False
         self._usefulness_ui_update('renew', current_user_reviewer,
             useful_total, useful_favorable)
 
     def _usefulness_ui_update(self, type, current_user_reviewer=False,
-        useful_total=0, useful_favorable=0):
+                              useful_total=0, useful_favorable=0):
         self._hide_usefulness_elements()
         #print "_usefulness_ui_update: %s" % type
         if type == 'renew':
@@ -539,7 +536,7 @@ class UIReview(Gtk.VBox):
         return datetime.datetime.strptime(raw_date_str, '%Y-%m-%d %H:%M:%S')
 
     def _delete_ui_update(self, type, current_user_reviewer=False,
-        action=None):
+                          action=None):
         self._hide_delete_elements()
         if type == 'renew':
             self._build_delete_flag_ui(current_user_reviewer)
@@ -607,7 +604,7 @@ class UIReview(Gtk.VBox):
 
     def _build(self, review_data, app_version, logged_in_person, useful_votes):
         # all the attributes of review_data may need markup escape,
-        # depening on if they are used as text or markup
+        # depending on if they are used as text or markup
         self.id = review_data.id
         self.person = review_data.reviewer_username
         displayname = review_data.reviewer_displayname
@@ -622,18 +619,18 @@ class UIReview(Gtk.VBox):
         modify_error = review_data.modify_error
 
         # upstream version
-        version = GObject.markup_escape_text(upstream_version(review_version))
+        version = GLib.markup_escape_text(upstream_version(review_version))
         # default string
         version_string = _("For version %(version)s") % {
             'version': version,
-            }
+        }
         # If its for the same version, show it as such
         if (review_version and
-            app_version and
-            upstream_version_compare(review_version, app_version) == 0):
+                app_version and
+                upstream_version_compare(review_version, app_version) == 0):
             version_string = _("For this version (%(version)s)") % {
                     'version': version,
-                    }
+            }
 
         m = '<small>%s</small>'
         self.version_label.set_markup(m % version_string)
@@ -646,7 +643,7 @@ class UIReview(Gtk.VBox):
 
         summary = Gtk.Label()
         try:
-            s = GObject.markup_escape_text(review_data.summary.encode("utf-8"))
+            s = GLib.markup_escape_text(review_data.summary.encode("utf-8"))
             summary.set_markup('<b>%s</b>' % s)
         except Exception:
             LOG.exception("_build() failed")
@@ -771,7 +768,7 @@ class UIReview(Gtk.VBox):
                     useful_total) % {
                         'useful_total': useful_total,
                         'useful_favorable': useful_favorable,
-                        }
+                    }
             else:
                 # user has not already voted for the review
                 s = gettext.ngettext(
@@ -782,7 +779,7 @@ class UIReview(Gtk.VBox):
                     useful_total) % {
                         'useful_total': useful_total,
                         'useful_favorable': useful_favorable,
-                        }
+                    }
         else:
         #only display these special strings if the user voted either way
             if already_voted:
@@ -797,7 +794,7 @@ class UIReview(Gtk.VBox):
                         useful_total) % {
                             'useful_total': useful_total,
                             'useful_favorable': useful_favorable,
-                            }
+                        }
             else:
                 if useful_total == 1:
                     s = _("You found this review unhelpful.")
@@ -810,7 +807,7 @@ class UIReview(Gtk.VBox):
                         useful_total) % {
                             'useful_total': useful_total,
                             'useful_favorable': useful_favorable,
-                            }
+                        }
 
         m = '<small>%s</small>'
         label = Gtk.Label()
@@ -819,7 +816,7 @@ class UIReview(Gtk.VBox):
         return label
 
     def _build_delete_flag_ui(self, current_user_reviewer, delete_error=False,
-        modify_error=False):
+                              modify_error=False):
         if delete_error:
             self._delete_ui_update('error', current_user_reviewer, 'deleting')
         elif modify_error:
@@ -855,16 +852,16 @@ class UIReview(Gtk.VBox):
 
         if person == self.logged_in_person:
             m = '%s (%s), %s' % (
-                GObject.markup_escape_text(utf8(correct_name)),
+                GLib.markup_escape_text(utf8(correct_name)),
                 # TRANSLATORS: displayed in a review after the persons name,
                 # e.g. "Jane Smith (that's you), 2011-02-11"
                 utf8(_(u"that\u2019s you")),
-                GObject.markup_escape_text(utf8(nice_date)))
+                GLib.markup_escape_text(utf8(nice_date)))
         else:
             try:
                 m = '%s, %s' % (
-                    GObject.markup_escape_text(correct_name.encode("utf-8")),
-                    GObject.markup_escape_text(nice_date))
+                    GLib.markup_escape_text(correct_name.encode("utf-8")),
+                    GLib.markup_escape_text(nice_date))
             except Exception:
                 LOG.exception("_who_when_markup failed")
                 m = "Error parsing name"
