@@ -20,6 +20,7 @@ import dbus
 import gc
 import gettext
 from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Gio
 import logging
 import math
@@ -42,7 +43,7 @@ from enums import Icons, APP_INSTALL_PATH_DELIMITER
 from paths import (
     SOFTWARE_CENTER_CACHE_DIR,
     OEM_CHANNEL_DESCRIPTOR,
-    )
+)
 
 from config import get_config
 
@@ -63,7 +64,7 @@ class UnimplementedError(Exception):
 class ExecutionTime(object):
     """
     Helper that can be used in with statements to have a simple
-    measure of the timming of a particular block of code, e.g.
+    measure of the timing of a particular block of code, e.g.
     with ExecutinTime("db flush"):
         db.flush()
     """
@@ -146,7 +147,7 @@ class TraceMemoryUsage(object):
             size, resident, share, text, lib, data, dt = f.readline().split()
         return {'resident': int(resident),
                 'data': int(data),
-               }
+                }
 
 
 def utf8(s):
@@ -183,7 +184,7 @@ def wait_for_apt_cache_ready(f):
         if not self.cache.ready:
             if window:
                 window.set_cursor(self.busy_cursor)
-            GObject.timeout_add(500, lambda: wrapper(*args, **kwargs))
+            GLib.timeout_add(500, lambda: wrapper(*args, **kwargs))
             return False
         # cache ready now
         if window:
@@ -194,7 +195,7 @@ def wait_for_apt_cache_ready(f):
 
 
 def capitalize_first_word(string):
-    """ this takes a package synopsis and uppercases the first  word's
+    """ this takes a package synopsis and uppercases the first word's
         first letter
     """
     if len(string) > 1 and string[0].isalpha() and not string[0].isupper():
@@ -204,11 +205,11 @@ def capitalize_first_word(string):
 
 def normalize_package_description(desc):
     """ this takes a package description and normalizes it
-        so that all uneeded \n are stripped away and all
+        so that all unneeded \n are stripped away and all
         enumerations are at the start of the line and start with a "*"
         E.g.:
-        Some potentially very long paragrah that is in a single line.
-        A new paragrpah.
+        Some potentially very long paragraph that is in a single line.
+        A new paragraph.
         A list:
         * item1
         * item2 that may again be very very long
@@ -465,9 +466,9 @@ def get_icon_from_theme(icons, iconname=None, iconsize=Icons.APP_ICON_SIZE,
     try:
         icon = icons.load_icon(iconname, iconsize, 0)
     except Exception as e:
-        LOG.warning(utf8("could not load icon '%s', displaying missing "
-                         "icon instead: %s ") % (
-                utf8(iconname), utf8(e.message)))
+        LOG.warning(
+            utf8("could not load icon '%s', displaying missing "
+                 "icon instead: %s ") % (utf8(iconname), utf8(e.message)))
         icon = icons.load_icon(missingicon, iconsize, 0)
     return icon
 
@@ -478,8 +479,7 @@ def get_file_path_from_iconname(icons, iconname=None,
     return the file path of the icon in the theme that corresponds to the
     given iconname, or None if it cannot be determined
     """
-    if (not iconname or
-        not icons.has_icon(iconname)):
+    if not iconname or not icons.has_icon(iconname):
         iconname = Icons.MISSING_APP
     try:
         icon_info = icons.lookup_icon(iconname, iconsize, 0)
@@ -518,8 +518,8 @@ def convert_desktop_file_to_installed_location(app_install_data_file_path,
             return installed_desktop_file_path
         # files in the extras archive have their desktop filenames prepended
         # by "extras-", so we check for that also (LP: #1012877)
-        extras_desktop_file_path = ("/usr/share/applications/"
-            "extras-%s.desktop" % pkgname)
+        extras_desktop_file_path = \
+            "/usr/share/applications/extras-%s.desktop" % pkgname
         if os.path.exists(extras_desktop_file_path):
             return extras_desktop_file_path
     LOG.warn("Could not determine the installed desktop file path for "
@@ -536,9 +536,9 @@ def clear_token_from_ubuntu_sso_sync(appname):
         DBUS_BUS_NAME,
         DBUS_CREDENTIALS_IFACE,
         DBUS_CREDENTIALS_PATH,
-        )
+    )
     # clean
-    loop = GObject.MainLoop()
+    loop = GLib.MainLoop()
     bus = dbus.SessionBus()
     obj = bus.get_object(bus_name=DBUS_BUS_NAME,
                          object_path=DBUS_CREDENTIALS_PATH,
@@ -550,7 +550,7 @@ def clear_token_from_ubuntu_sso_sync(appname):
     proxy.connect_to_signal("CredentialsError", loop.quit)
     proxy.clear_credentials(appname, {})
     # ensure we don't hang forever here
-    GObject.timeout_add_seconds(2, loop.quit)
+    GLib.timeout_add_seconds(2, loop.quit)
     # run the mainloop until the credentials are clear
     loop.run()
 
@@ -565,7 +565,7 @@ def get_nice_date_string(cur_t):
 
     if days < 1:
         if secs < 120:   # less than 2 minute ago
-            s = _('a few minutes ago')   # dont be fussy
+            s = _('a few minutes ago')   # don't be fussy
 
         elif secs < 3600:   # less than an hour ago
             s = gettext.ngettext("%(min)i minute ago",
@@ -602,15 +602,16 @@ def get_exec_line_from_desktop(desktop_file):
 
 def is_no_display_desktop_file(desktop_file):
     nd = _get_from_desktop_file(desktop_file, "NoDisplay")
-    # desktop spec says the booleans are always either "true" or "false
+    # desktop spec says the booleans are always either "true" or "false"
     if nd == "true":
         return True
     return False
 
 
 def get_nice_size(n_bytes):
-    nice_size = lambda s: [(s % 1024 ** i and "%.1f" % (s / 1024.0 ** i) or
-        str(s / 1024 ** i)) + x.strip() for i, x in enumerate(' KMGTPEZY')
+    nice_size = lambda s: [
+        (s % 1024 ** i and "%.1f" % (s / 1024.0 ** i) or
+         str(s / 1024 ** i)) + x.strip() for i, x in enumerate(' KMGTPEZY')
         if s < 1024 ** (i + 1) or i == 8][0]
     return nice_size(n_bytes)
 
@@ -619,14 +620,11 @@ def save_person_to_config(username):
     """ save the specified username value for Ubuntu SSO to the config file
     """
     # FIXME: ideally this would be stored in ubuntu-sso-client
-    #        but it doesn't so we store it here
+    #        but it doesn't, so we store it here
     curr_name = get_person_from_config()
     if curr_name != username:
         config = get_config()
-        if not config.has_section("reviews"):
-            config.add_section("reviews")
-        config.set("reviews", "username", username)
-        config.write()
+        config.reviews_username = username
         # refresh usefulness cache in the background once we know
         # the person
         from backend.reviews import UsefulnessCache
@@ -638,9 +636,7 @@ def get_person_from_config():
     """ get the username value for Ubuntu SSO from the config file
     """
     cfg = get_config()
-    if cfg.has_option("reviews", "username"):
-        return cfg.get("reviews", "username")
-    return None
+    return cfg.reviews_username
 
 
 def pnormaldist(qn):
@@ -702,7 +698,7 @@ def calc_dr(ratings, power=0.1):
 # is not good enough
 def split_icon_ext(iconname):
     """ return the basename of a icon if it matches a known icon
-        extenstion like tiff, gif, jpg, svg, png, xpm, ico
+        extension like tiff, gif, jpg, svg, png, xpm, ico
     """
     SUPPORTED_EXTENSIONS = [".tiff", ".tif", ".gif", ".jpg", ".jpeg", ".svg",
                             ".png", ".xpm", ".ico"]
@@ -735,7 +731,7 @@ def mangle_paths_if_running_in_local_checkout():
         if os.path.exists(path):
             softwarecenter.paths.APP_INSTALL_PATH = './build/share/app-install'
             logging.warn("using local APP_INSTALL_PATH: %s" %
-                             softwarecenter.paths.APP_INSTALL_PATH)
+                         softwarecenter.paths.APP_INSTALL_PATH)
     else:
         datadir = softwarecenter.paths.datadir
         xapian_base_path = softwarecenter.paths.XAPIAN_BASE_PATH
@@ -810,7 +806,7 @@ def ensure_file_writable_and_delete_if_not(file_path):
 def safe_makedirs(dir_path):
     """ This function can be used in place of a straight os.makedirs to
         handle the possibility of a race condition when more than one
-        process may potentially be creating the same directory, it will
+        process may potentially be creating the same directory. It will
         not fail if two processes try to create the same dir at the same
         time
     """
@@ -829,7 +825,7 @@ def safe_makedirs(dir_path):
 
 
 def get_oem_channel_descriptor(path=OEM_CHANNEL_DESCRIPTOR):
-    """Return the ubuntu  distribution channel descriptor or a empty string """
+    """Return the ubuntu distribution channel descriptor or a empty string """
     if not os.path.exists(path):
         return ""
     with open(path) as f:
@@ -854,7 +850,7 @@ class SimpleFileDownloader(GObject.GObject):
                   GObject.TYPE_NONE,
                   (GObject.TYPE_PYOBJECT,
                    GObject.TYPE_PYOBJECT,),),
-        }
+    }
 
     def __init__(self):
         GObject.GObject.__init__(self)
@@ -872,8 +868,8 @@ class SimpleFileDownloader(GObject.GObject):
             instead a permanent cache dir - no etag or timestamp
             checks are performed.
         """
-        self.LOG.debug("download_file: %s %s %s" % (
-                url, dest_file_path, use_cache))
+        self.LOG.debug(
+            "download_file: %s %s %s" % (url, dest_file_path, use_cache))
 
         # cancel anything pending to avoid race conditions
         # like bug #839462
@@ -927,14 +923,14 @@ class SimpleFileDownloader(GObject.GObject):
         """This function will ensure that the url we requested to download
            earlier matches that is now downloaded.
         """
-        # this function is needed as there is a rance condition when the
-        # operation is finished but the signal is not delivered yet (its
+        # this function is needed as there is a race condition when the
+        # operation is finished but the signal is not delivered yet (it's
         # still in the gtk event loop). in this case there is nothing to
         # self._cancel but self.url/self.dest_file_path will still point to
         # the wrong file
         if self.url != want_url:
-            self.LOG.warn("url changed from '%s' to '%s'" % (
-                    want_url, self.url))
+            self.LOG.warn(
+                "url changed from '%s' to '%s'" % (want_url, self.url))
             return False
         return True
 
@@ -969,7 +965,7 @@ class SimpleFileDownloader(GObject.GObject):
         try:
             res, content, etag = f.load_contents_finish(result)
         except Exception as e:
-            # i witnissed a strange error[1], so make the loader robust in this
+            # I witnessed a strange error[1], so make the loader robust in this
             # situation
             # 1. content = f.load_contents_finish(result)[0]
             #    Gio.Error: DBus error org.freedesktop.DBus.Error.NoReply
@@ -983,9 +979,9 @@ class SimpleFileDownloader(GObject.GObject):
         self.emit('file-download-complete', self.dest_file_path)
 
 
-# those helpers are packaging system specific
+# those helpers are packaging-system specific
 from softwarecenter.db.pkginfo import get_pkg_info
-# do not call here get_pkg_info, since package switch may not have been set
+# do not call get_pkg_info here, since package switch may not have been set
 # instead use an anonymous function delay
 upstream_version_compare = lambda v1, v2: \
     get_pkg_info().upstream_version_compare(v1, v2)
