@@ -7,7 +7,7 @@ import urllib
 
 import xapian
 
-from gi.repository import Gdk, GObject, Gtk
+from gi.repository import Gdk, Gtk, GLib
 from mock import Mock
 
 import softwarecenter.distro
@@ -177,8 +177,8 @@ def on_entry_changed(widget, data):
                 do_events()
 
     if widget.stamp:
-        GObject.source_remove(widget.stamp)
-    widget.stamp = GObject.timeout_add(250, _work)
+        GLib.source_remove(widget.stamp)
+    widget.stamp = GLib.timeout_add(250, _work)
 
 
 def get_test_window_appview():
@@ -535,7 +535,7 @@ def get_test_window_purchaseview(url=None):
 
     # useful for debugging
     #d.connect("key-press-event", _on_key_press)
-    #GObject.timeout_add_seconds(1, _generate_events, d)
+    #GLib.timeout_add_seconds(1, _generate_events, d)
 
     widget = purchaseview.PurchaseView()
     widget.config = Mock()
@@ -913,7 +913,7 @@ def get_test_window_oneconfviews():
     w.register_computer("", "This computer should be first")
     w.select_first()
 
-    GObject.timeout_add_seconds(5, w.register_computer, "EEEEE", "NameE")
+    GLib.timeout_add_seconds(5, w.register_computer, "EEEEE", "NameE")
 
     def print_selected_hostid(widget, hostid, hostname):
         print("%s selected for %s" % (hostid, hostname))
@@ -970,7 +970,7 @@ def get_test_spinner_window():
 
     win = get_test_window(child=spinner_notebook)
     spinner_notebook.show_spinner("Loading for 1s ...")
-    GObject.timeout_add_seconds(1, lambda: spinner_notebook.hide_spinner())
+    GLib.timeout_add_seconds(1, lambda: spinner_notebook.hide_spinner())
     return win
 
 
@@ -1146,7 +1146,7 @@ if __name__ == '__main__':
             if isinstance(result, Gtk.Dialog):
                 response = result.run()
                 result.hide()
-                GObject.timeout_add(1, Gtk.main_quit)
+                GLib.timeout_add(1, Gtk.main_quit)
             elif isinstance(result, Gtk.Window):
                 result.connect("destroy", Gtk.main_quit)
             Gtk.main()
