@@ -7,7 +7,7 @@ import time
 import unittest
 import xapian
 
-from gi.repository import GObject
+from gi.repository import GLib
 from piston_mini_client import PistonResponseObject
 from mock import Mock, patch
 
@@ -301,7 +301,7 @@ class TestDatabase(unittest.TestCase):
         self.assertEqual(appdetails.installation_date, None)
         # then we need to wait until the history is loaded in the idle
         # handler
-        context = GObject.main_context_default()
+        context = GLib.main_context_default()
         while context.pending():
             context.iteration()
         # ... and finally we test that its really there
@@ -468,8 +468,8 @@ app-popcon	4	# app-install .desktop popcon rank
         self.assertNotEqual(axi_values, {})
         #print axi_values
 
-    @unittest.skipIf(not os.path.exists("/var/lib/apt-xapian-index/index"), 
-                     "Need populated apt-xapian-index for this test")
+    @unittest.skipIf(os.path.exists("/var/lib/debtags/package-tags"), 
+                     "a-x-i will has not run apttags.py plugin")
     def test_appdetails(self):
         db = get_test_db()
         # see "apt-cache show casper|grep ^Tag"
